@@ -1,9 +1,11 @@
-from taskw.warrior import TaskWarrior
+from taskw.warrior import TaskWarrior, TaskWarriorExperimental
 from taskw.utils import clean_task, encode_task, decode_task
 
 __all__ = [
     TaskWarrior,
+    TaskWarriorExperimental,
     clean_task,
     encode_task,
     decode_task,
+    encode_task_experimental,
 ]
